@@ -3,6 +3,7 @@ import requests
 
 from .data import string_to_raw, float_to_raw, int_to_raw, bool_to_raw
 from .stream import Stream
+from .universe import load_universe
 
 
 class Client:
@@ -35,7 +36,7 @@ class Client:
         })
 
         if resp.status_code != 200:
-            return False
+            raise RuntimeError(f"login failed: " + str(resp.content, "ascii"))
 
         self.__user_id = resp.json()['userId']
         self.__refresh_token = resp.json()['refreshToken']
@@ -56,6 +57,13 @@ class Client:
             raise RuntimeError('could not resolve universe')
         self.__space = self.__universe['space']
 
+    def load_universe(self, name):
+        universe_id = self.resolve_universe(name)
+        if not universe_id:
+            return None
+        resp = requests.get(f'{self.__app_url}universe/{universe_id}/export?o=1')
+        return load_universe(resp.content)
+
     def resolve(self, identifier):
         if isinstance(identifier, list):
             return [self.resolve(i) for i in identifier]
@@ -394,5 +402,5 @@ class Client:
         return {
             'Authorization': f'Baerer {self.__access_token}',
             'x-vy-spaces': ','.join([v['token'] for (k, v) in self.__space_tokens.items()]),
-            'x-vy-bypass-cache': '1' if cached else '0',
+            'x-vy-bypass-cache': '0' if cached else '1',
         }
